# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/prediction/proto/prediction_obstacle.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import error_code_pb2 as modules_dot_common_dot_proto_dot_error__code__pb2
from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2
from modules.prediction.proto import scenario_pb2 as modules_dot_prediction_dot_proto_dot_scenario__pb2
from modules.perception.proto import perception_obstacle_pb2 as modules_dot_perception_dot_proto_dot_perception__obstacle__pb2
from modules.prediction.proto import feature_pb2 as modules_dot_prediction_dot_proto_dot_feature__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/prediction/proto/prediction_obstacle.proto',
  package='apollo.prediction',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n2modules/prediction/proto/prediction_obstacle.proto\x12\x11\x61pollo.prediction\x1a%modules/common/proto/error_code.proto\x1a!modules/common/proto/header.proto\x1a\'modules/prediction/proto/scenario.proto\x1a\x32modules/perception/proto/perception_obstacle.proto\x1a&modules/prediction/proto/feature.proto\"\xf6\x01\n\x0eObstacleIntent\x12=\n\x04type\x18\x01 \x01(\x0e\x32&.apollo.prediction.ObstacleIntent.Type:\x07UNKNOWN\"\xa4\x01\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04STOP\x10\x01\x12\x0e\n\nSTATIONARY\x10\x02\x12\n\n\x06MOVING\x10\x03\x12\x0f\n\x0b\x43HANGE_LANE\x10\x04\x12\x14\n\x10LOW_ACCELERATION\x10\x05\x12\x15\n\x11HIGH_ACCELERATION\x10\x06\x12\x14\n\x10LOW_DECELERATION\x10\x07\x12\x15\n\x11HIGH_DECELERATION\x10\x08\"{\n\x06Intent\x12\x35\n\x04type\x18\x01 \x01(\x0e\x32\x1e.apollo.prediction.Intent.Type:\x07UNKNOWN\":\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04STOP\x10\x01\x12\n\n\x06\x43RUISE\x10\x02\x12\x0f\n\x0b\x43HANGE_LANE\x10\x03\"\xe9\x02\n\x12PredictionObstacle\x12\x42\n\x13perception_obstacle\x18\x01 \x01(\x0b\x32%.apollo.perception.PerceptionObstacle\x12\x11\n\ttimestamp\x18\x02 \x01(\x01\x12\x18\n\x10predicted_period\x18\x03 \x01(\x01\x12\x31\n\ntrajectory\x18\x04 \x03(\x0b\x32\x1d.apollo.prediction.Trajectory\x12\x31\n\x06intent\x18\x05 \x01(\x0b\x32!.apollo.prediction.ObstacleIntent\x12\x35\n\x08priority\x18\x06 \x01(\x0b\x32#.apollo.prediction.ObstaclePriority\x12\x18\n\tis_static\x18\x07 \x01(\x08:\x05\x66\x61lse\x12+\n\x07\x66\x65\x61ture\x18\x08 \x03(\x0b\x32\x1a.apollo.prediction.Feature\"\xc3\x02\n\x13PredictionObstacles\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\x42\n\x13prediction_obstacle\x18\x02 \x03(\x0b\x32%.apollo.prediction.PredictionObstacle\x12\x37\n\x15perception_error_code\x18\x03 \x01(\x0e\x32\x18.apollo.common.ErrorCode\x12\x17\n\x0fstart_timestamp\x18\x04 \x01(\x01\x12\x15\n\rend_timestamp\x18\x05 \x01(\x01\x12)\n\x06intent\x18\x06 \x01(\x0b\x32\x19.apollo.prediction.Intent\x12-\n\x08scenario\x18\x07 \x01(\x0b\x32\x1b.apollo.prediction.Scenario'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_error__code__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,modules_dot_prediction_dot_proto_dot_scenario__pb2.DESCRIPTOR,modules_dot_perception_dot_proto_dot_perception__obstacle__pb2.DESCRIPTOR,modules_dot_prediction_dot_proto_dot_feature__pb2.DESCRIPTOR,])



_OBSTACLEINTENT_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='apollo.prediction.ObstacleIntent.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATIONARY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MOVING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHANGE_LANE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOW_ACCELERATION', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGH_ACCELERATION', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOW_DECELERATION', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGH_DECELERATION', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=363,
  serialized_end=527,
)
_sym_db.RegisterEnumDescriptor(_OBSTACLEINTENT_TYPE)

_INTENT_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='apollo.prediction.Intent.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CRUISE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHANGE_LANE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=594,
  serialized_end=652,
)
_sym_db.RegisterEnumDescriptor(_INTENT_TYPE)


_OBSTACLEINTENT = _descriptor.Descriptor(
  name='ObstacleIntent',
  full_name='apollo.prediction.ObstacleIntent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.prediction.ObstacleIntent.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _OBSTACLEINTENT_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=281,
  serialized_end=527,
)


_INTENT = _descriptor.Descriptor(
  name='Intent',
  full_name='apollo.prediction.Intent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.prediction.Intent.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _INTENT_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=529,
  serialized_end=652,
)


_PREDICTIONOBSTACLE = _descriptor.Descriptor(
  name='PredictionObstacle',
  full_name='apollo.prediction.PredictionObstacle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='perception_obstacle', full_name='apollo.prediction.PredictionObstacle.perception_obstacle', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='apollo.prediction.PredictionObstacle.timestamp', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='predicted_period', full_name='apollo.prediction.PredictionObstacle.predicted_period', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trajectory', full_name='apollo.prediction.PredictionObstacle.trajectory', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='intent', full_name='apollo.prediction.PredictionObstacle.intent', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priority', full_name='apollo.prediction.PredictionObstacle.priority', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_static', full_name='apollo.prediction.PredictionObstacle.is_static', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature', full_name='apollo.prediction.PredictionObstacle.feature', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=655,
  serialized_end=1016,
)


_PREDICTIONOBSTACLES = _descriptor.Descriptor(
  name='PredictionObstacles',
  full_name='apollo.prediction.PredictionObstacles',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.prediction.PredictionObstacles.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prediction_obstacle', full_name='apollo.prediction.PredictionObstacles.prediction_obstacle', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='perception_error_code', full_name='apollo.prediction.PredictionObstacles.perception_error_code', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_timestamp', full_name='apollo.prediction.PredictionObstacles.start_timestamp', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_timestamp', full_name='apollo.prediction.PredictionObstacles.end_timestamp', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='intent', full_name='apollo.prediction.PredictionObstacles.intent', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scenario', full_name='apollo.prediction.PredictionObstacles.scenario', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1019,
  serialized_end=1342,
)

_OBSTACLEINTENT.fields_by_name['type'].enum_type = _OBSTACLEINTENT_TYPE
_OBSTACLEINTENT_TYPE.containing_type = _OBSTACLEINTENT
_INTENT.fields_by_name['type'].enum_type = _INTENT_TYPE
_INTENT_TYPE.containing_type = _INTENT
_PREDICTIONOBSTACLE.fields_by_name['perception_obstacle'].message_type = modules_dot_perception_dot_proto_dot_perception__obstacle__pb2._PERCEPTIONOBSTACLE
_PREDICTIONOBSTACLE.fields_by_name['trajectory'].message_type = modules_dot_prediction_dot_proto_dot_feature__pb2._TRAJECTORY
_PREDICTIONOBSTACLE.fields_by_name['intent'].message_type = _OBSTACLEINTENT
_PREDICTIONOBSTACLE.fields_by_name['priority'].message_type = modules_dot_prediction_dot_proto_dot_feature__pb2._OBSTACLEPRIORITY
_PREDICTIONOBSTACLE.fields_by_name['feature'].message_type = modules_dot_prediction_dot_proto_dot_feature__pb2._FEATURE
_PREDICTIONOBSTACLES.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_PREDICTIONOBSTACLES.fields_by_name['prediction_obstacle'].message_type = _PREDICTIONOBSTACLE
_PREDICTIONOBSTACLES.fields_by_name['perception_error_code'].enum_type = modules_dot_common_dot_proto_dot_error__code__pb2._ERRORCODE
_PREDICTIONOBSTACLES.fields_by_name['intent'].message_type = _INTENT
_PREDICTIONOBSTACLES.fields_by_name['scenario'].message_type = modules_dot_prediction_dot_proto_dot_scenario__pb2._SCENARIO
DESCRIPTOR.message_types_by_name['ObstacleIntent'] = _OBSTACLEINTENT
DESCRIPTOR.message_types_by_name['Intent'] = _INTENT
DESCRIPTOR.message_types_by_name['PredictionObstacle'] = _PREDICTIONOBSTACLE
DESCRIPTOR.message_types_by_name['PredictionObstacles'] = _PREDICTIONOBSTACLES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ObstacleIntent = _reflection.GeneratedProtocolMessageType('ObstacleIntent', (_message.Message,), {
  'DESCRIPTOR' : _OBSTACLEINTENT,
  '__module__' : 'modules.prediction.proto.prediction_obstacle_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.ObstacleIntent)
  })
_sym_db.RegisterMessage(ObstacleIntent)

Intent = _reflection.GeneratedProtocolMessageType('Intent', (_message.Message,), {
  'DESCRIPTOR' : _INTENT,
  '__module__' : 'modules.prediction.proto.prediction_obstacle_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.Intent)
  })
_sym_db.RegisterMessage(Intent)

PredictionObstacle = _reflection.GeneratedProtocolMessageType('PredictionObstacle', (_message.Message,), {
  'DESCRIPTOR' : _PREDICTIONOBSTACLE,
  '__module__' : 'modules.prediction.proto.prediction_obstacle_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.PredictionObstacle)
  })
_sym_db.RegisterMessage(PredictionObstacle)

PredictionObstacles = _reflection.GeneratedProtocolMessageType('PredictionObstacles', (_message.Message,), {
  'DESCRIPTOR' : _PREDICTIONOBSTACLES,
  '__module__' : 'modules.prediction.proto.prediction_obstacle_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.PredictionObstacles)
  })
_sym_db.RegisterMessage(PredictionObstacles)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/audio/proto/audio_conf.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/audio/proto/audio_conf.proto',
  package='apollo.audio',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$modules/audio/proto/audio_conf.proto\x12\x0c\x61pollo.audio\"\xae\x01\n\tTopicConf\x12\x1d\n\x15\x61udio_data_topic_name\x18\x01 \x01(\t\x12\"\n\x1a\x61udio_detection_topic_name\x18\x02 \x01(\t\x12\x1f\n\x17localization_topic_name\x18\x03 \x01(\t\x12\x1e\n\x16\x61udio_event_topic_name\x18\x04 \x01(\t\x12\x1d\n\x15perception_topic_name\x18\x05 \x01(\t\"[\n\tAudioConf\x12+\n\ntopic_conf\x18\x01 \x01(\x0b\x32\x17.apollo.audio.TopicConf\x12!\n\x19respeaker_extrinsics_path\x18\x02 \x01(\t'
)




_TOPICCONF = _descriptor.Descriptor(
  name='TopicConf',
  full_name='apollo.audio.TopicConf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='audio_data_topic_name', full_name='apollo.audio.TopicConf.audio_data_topic_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audio_detection_topic_name', full_name='apollo.audio.TopicConf.audio_detection_topic_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='localization_topic_name', full_name='apollo.audio.TopicConf.localization_topic_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audio_event_topic_name', full_name='apollo.audio.TopicConf.audio_event_topic_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='perception_topic_name', full_name='apollo.audio.TopicConf.perception_topic_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55,
  serialized_end=229,
)


_AUDIOCONF = _descriptor.Descriptor(
  name='AudioConf',
  full_name='apollo.audio.AudioConf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='topic_conf', full_name='apollo.audio.AudioConf.topic_conf', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='respeaker_extrinsics_path', full_name='apollo.audio.AudioConf.respeaker_extrinsics_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=231,
  serialized_end=322,
)

_AUDIOCONF.fields_by_name['topic_conf'].message_type = _TOPICCONF
DESCRIPTOR.message_types_by_name['TopicConf'] = _TOPICCONF
DESCRIPTOR.message_types_by_name['AudioConf'] = _AUDIOCONF
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TopicConf = _reflection.GeneratedProtocolMessageType('TopicConf', (_message.Message,), {
  'DESCRIPTOR' : _TOPICCONF,
  '__module__' : 'modules.audio.proto.audio_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.audio.TopicConf)
  })
_sym_db.RegisterMessage(TopicConf)

AudioConf = _reflection.GeneratedProtocolMessageType('AudioConf', (_message.Message,), {
  'DESCRIPTOR' : _AUDIOCONF,
  '__module__' : 'modules.audio.proto.audio_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.audio.AudioConf)
  })
_sym_db.RegisterMessage(AudioConf)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/perception/proto/perception_lane.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2
from modules.perception.proto import perception_camera_pb2 as modules_dot_perception_dot_proto_dot_perception__camera__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/perception/proto/perception_lane.proto',
  package='apollo.perception',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.modules/perception/proto/perception_lane.proto\x12\x11\x61pollo.perception\x1a!modules/common/proto/header.proto\x1a\x30modules/perception/proto/perception_camera.proto\"\xa3\x02\n\x0fPerceptionLanes\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\x14\n\x0csource_topic\x18\x02 \x01(\t\x12I\n\nerror_code\x18\x03 \x01(\x0e\x32).apollo.perception.camera.CameraErrorCode:\nERROR_NONE\x12\x45\n\x11\x63\x61mera_calibrator\x18\x04 \x01(\x0b\x32*.apollo.perception.camera.CameraCalibrator\x12\x41\n\x0f\x63\x61mera_laneline\x18\x05 \x03(\x0b\x32(.apollo.perception.camera.CameraLaneLine'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,modules_dot_perception_dot_proto_dot_perception__camera__pb2.DESCRIPTOR,])




_PERCEPTIONLANES = _descriptor.Descriptor(
  name='PerceptionLanes',
  full_name='apollo.perception.PerceptionLanes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.perception.PerceptionLanes.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_topic', full_name='apollo.perception.PerceptionLanes.source_topic', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_code', full_name='apollo.perception.PerceptionLanes.error_code', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camera_calibrator', full_name='apollo.perception.PerceptionLanes.camera_calibrator', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camera_laneline', full_name='apollo.perception.PerceptionLanes.camera_laneline', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=155,
  serialized_end=446,
)

_PERCEPTIONLANES.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_PERCEPTIONLANES.fields_by_name['error_code'].enum_type = modules_dot_perception_dot_proto_dot_perception__camera__pb2._CAMERAERRORCODE
_PERCEPTIONLANES.fields_by_name['camera_calibrator'].message_type = modules_dot_perception_dot_proto_dot_perception__camera__pb2._CAMERACALIBRATOR
_PERCEPTIONLANES.fields_by_name['camera_laneline'].message_type = modules_dot_perception_dot_proto_dot_perception__camera__pb2._CAMERALANELINE
DESCRIPTOR.message_types_by_name['PerceptionLanes'] = _PERCEPTIONLANES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PerceptionLanes = _reflection.GeneratedProtocolMessageType('PerceptionLanes', (_message.Message,), {
  'DESCRIPTOR' : _PERCEPTIONLANES,
  '__module__' : 'modules.perception.proto.perception_lane_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.PerceptionLanes)
  })
_sym_db.RegisterMessage(PerceptionLanes)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/tools/navigator/dbmap/proto/dbmap.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/tools/navigator/dbmap/proto/dbmap.proto',
  package='apollo.dbmap',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/modules/tools/navigator/dbmap/proto/dbmap.proto\x12\x0c\x61pollo.dbmap\"F\n\x07\x44\x42Point\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x12\t\n\x01z\x18\x03 \x01(\x01\x12\t\n\x01s\x18\x04 \x01(\x01\x12\x0f\n\x07heading\x18\x05 \x01(\x01\".\n\x06\x44\x42Line\x12$\n\x05point\x18\x01 \x03(\x0b\x32\x15.apollo.dbmap.DBPoint\"o\n\x12\x44\x42NeighbourSegment\x12\x0f\n\x07start_s\x18\x01 \x01(\x01\x12\r\n\x05\x65nd_s\x18\x02 \x01(\x01\x12\x0f\n\x07path_id\x18\x03 \x01(\t\x12\x14\n\x0cpath_start_s\x18\x04 \x01(\x01\x12\x12\n\npath_end_s\x18\x05 \x01(\x01\"D\n\x0f\x44\x42NeighbourPath\x12\x31\n\x07segment\x18\x01 \x03(\x0b\x32 .apollo.dbmap.DBNeighbourSegment\"\xad\x02\n\x06\x44\x42Path\x12\n\n\x02id\x18\x01 \x01(\t\x12\"\n\x04path\x18\x02 \x03(\x0b\x32\x14.apollo.dbmap.DBLine\x12*\n\x0cleft_bounday\x18\x03 \x03(\x0b\x32\x14.apollo.dbmap.DBLine\x12+\n\rright_bounday\x18\x04 \x03(\x0b\x32\x14.apollo.dbmap.DBLine\x12\x30\n\tleft_path\x18\x05 \x03(\x0b\x32\x1d.apollo.dbmap.DBNeighbourPath\x12\x31\n\nright_path\x18\x06 \x03(\x0b\x32\x1d.apollo.dbmap.DBNeighbourPath\x12\x35\n\x0e\x64uplicate_path\x18\x07 \x03(\x0b\x32\x1d.apollo.dbmap.DBNeighbourPath\",\n\x05\x44\x42Map\x12#\n\x05paths\x18\x01 \x03(\x0b\x32\x14.apollo.dbmap.DBPath'
)




_DBPOINT = _descriptor.Descriptor(
  name='DBPoint',
  full_name='apollo.dbmap.DBPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='apollo.dbmap.DBPoint.x', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='apollo.dbmap.DBPoint.y', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='apollo.dbmap.DBPoint.z', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='s', full_name='apollo.dbmap.DBPoint.s', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading', full_name='apollo.dbmap.DBPoint.heading', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=65,
  serialized_end=135,
)


_DBLINE = _descriptor.Descriptor(
  name='DBLine',
  full_name='apollo.dbmap.DBLine',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='point', full_name='apollo.dbmap.DBLine.point', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=137,
  serialized_end=183,
)


_DBNEIGHBOURSEGMENT = _descriptor.Descriptor(
  name='DBNeighbourSegment',
  full_name='apollo.dbmap.DBNeighbourSegment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_s', full_name='apollo.dbmap.DBNeighbourSegment.start_s', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_s', full_name='apollo.dbmap.DBNeighbourSegment.end_s', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path_id', full_name='apollo.dbmap.DBNeighbourSegment.path_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path_start_s', full_name='apollo.dbmap.DBNeighbourSegment.path_start_s', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path_end_s', full_name='apollo.dbmap.DBNeighbourSegment.path_end_s', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=185,
  serialized_end=296,
)


_DBNEIGHBOURPATH = _descriptor.Descriptor(
  name='DBNeighbourPath',
  full_name='apollo.dbmap.DBNeighbourPath',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='segment', full_name='apollo.dbmap.DBNeighbourPath.segment', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=298,
  serialized_end=366,
)


_DBPATH = _descriptor.Descriptor(
  name='DBPath',
  full_name='apollo.dbmap.DBPath',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.dbmap.DBPath.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='apollo.dbmap.DBPath.path', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_bounday', full_name='apollo.dbmap.DBPath.left_bounday', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_bounday', full_name='apollo.dbmap.DBPath.right_bounday', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_path', full_name='apollo.dbmap.DBPath.left_path', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_path', full_name='apollo.dbmap.DBPath.right_path', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='duplicate_path', full_name='apollo.dbmap.DBPath.duplicate_path', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=369,
  serialized_end=670,
)


_DBMAP = _descriptor.Descriptor(
  name='DBMap',
  full_name='apollo.dbmap.DBMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='paths', full_name='apollo.dbmap.DBMap.paths', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=672,
  serialized_end=716,
)

_DBLINE.fields_by_name['point'].message_type = _DBPOINT
_DBNEIGHBOURPATH.fields_by_name['segment'].message_type = _DBNEIGHBOURSEGMENT
_DBPATH.fields_by_name['path'].message_type = _DBLINE
_DBPATH.fields_by_name['left_bounday'].message_type = _DBLINE
_DBPATH.fields_by_name['right_bounday'].message_type = _DBLINE
_DBPATH.fields_by_name['left_path'].message_type = _DBNEIGHBOURPATH
_DBPATH.fields_by_name['right_path'].message_type = _DBNEIGHBOURPATH
_DBPATH.fields_by_name['duplicate_path'].message_type = _DBNEIGHBOURPATH
_DBMAP.fields_by_name['paths'].message_type = _DBPATH
DESCRIPTOR.message_types_by_name['DBPoint'] = _DBPOINT
DESCRIPTOR.message_types_by_name['DBLine'] = _DBLINE
DESCRIPTOR.message_types_by_name['DBNeighbourSegment'] = _DBNEIGHBOURSEGMENT
DESCRIPTOR.message_types_by_name['DBNeighbourPath'] = _DBNEIGHBOURPATH
DESCRIPTOR.message_types_by_name['DBPath'] = _DBPATH
DESCRIPTOR.message_types_by_name['DBMap'] = _DBMAP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DBPoint = _reflection.GeneratedProtocolMessageType('DBPoint', (_message.Message,), {
  'DESCRIPTOR' : _DBPOINT,
  '__module__' : 'modules.tools.navigator.dbmap.proto.dbmap_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dbmap.DBPoint)
  })
_sym_db.RegisterMessage(DBPoint)

DBLine = _reflection.GeneratedProtocolMessageType('DBLine', (_message.Message,), {
  'DESCRIPTOR' : _DBLINE,
  '__module__' : 'modules.tools.navigator.dbmap.proto.dbmap_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dbmap.DBLine)
  })
_sym_db.RegisterMessage(DBLine)

DBNeighbourSegment = _reflection.GeneratedProtocolMessageType('DBNeighbourSegment', (_message.Message,), {
  'DESCRIPTOR' : _DBNEIGHBOURSEGMENT,
  '__module__' : 'modules.tools.navigator.dbmap.proto.dbmap_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dbmap.DBNeighbourSegment)
  })
_sym_db.RegisterMessage(DBNeighbourSegment)

DBNeighbourPath = _reflection.GeneratedProtocolMessageType('DBNeighbourPath', (_message.Message,), {
  'DESCRIPTOR' : _DBNEIGHBOURPATH,
  '__module__' : 'modules.tools.navigator.dbmap.proto.dbmap_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dbmap.DBNeighbourPath)
  })
_sym_db.RegisterMessage(DBNeighbourPath)

DBPath = _reflection.GeneratedProtocolMessageType('DBPath', (_message.Message,), {
  'DESCRIPTOR' : _DBPATH,
  '__module__' : 'modules.tools.navigator.dbmap.proto.dbmap_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dbmap.DBPath)
  })
_sym_db.RegisterMessage(DBPath)

DBMap = _reflection.GeneratedProtocolMessageType('DBMap', (_message.Message,), {
  'DESCRIPTOR' : _DBMAP,
  '__module__' : 'modules.tools.navigator.dbmap.proto.dbmap_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dbmap.DBMap)
  })
_sym_db.RegisterMessage(DBMap)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/common/vehicle_model/proto/vehicle_model_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/common/vehicle_model/proto/vehicle_model_config.proto',
  package='apollo.common',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n=modules/common/vehicle_model/proto/vehicle_model_config.proto\x12\rapollo.common\"\xab\x03\n\x12VehicleModelConfig\x12?\n\nmodel_type\x18\x01 \x01(\x0e\x32+.apollo.common.VehicleModelConfig.ModelType\x12Z\n\x1arc_kinematic_bicycle_model\x18\x02 \x01(\x0b\x32\x36.apollo.common.RearCenteredKinematicBicycleModelConfig\x12W\n\x1a\x63omc_dynamic_bicycle_model\x18\x03 \x01(\x0b\x32\x33.apollo.common.ComCenteredDynamicBicycleModelConfig\x12\x30\n\tmlp_model\x18\x04 \x01(\x0b\x32\x1d.apollo.common.MlpModelConfig\"m\n\tModelType\x12)\n%REAR_CENTERED_KINEMATIC_BICYCLE_MODEL\x10\x00\x12&\n\"COM_CENTERED_DYNAMIC_BICYCLE_MODEL\x10\x01\x12\r\n\tMLP_MODEL\x10\x02\"5\n\'RearCenteredKinematicBicycleModelConfig\x12\n\n\x02\x64t\x18\x01 \x01(\x01\"2\n$ComCenteredDynamicBicycleModelConfig\x12\n\n\x02\x64t\x18\x01 \x01(\x01\"\x1c\n\x0eMlpModelConfig\x12\n\n\x02\x64t\x18\x01 \x01(\x01'
)



_VEHICLEMODELCONFIG_MODELTYPE = _descriptor.EnumDescriptor(
  name='ModelType',
  full_name='apollo.common.VehicleModelConfig.ModelType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REAR_CENTERED_KINEMATIC_BICYCLE_MODEL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COM_CENTERED_DYNAMIC_BICYCLE_MODEL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MLP_MODEL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=399,
  serialized_end=508,
)
_sym_db.RegisterEnumDescriptor(_VEHICLEMODELCONFIG_MODELTYPE)


_VEHICLEMODELCONFIG = _descriptor.Descriptor(
  name='VehicleModelConfig',
  full_name='apollo.common.VehicleModelConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_type', full_name='apollo.common.VehicleModelConfig.model_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rc_kinematic_bicycle_model', full_name='apollo.common.VehicleModelConfig.rc_kinematic_bicycle_model', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='comc_dynamic_bicycle_model', full_name='apollo.common.VehicleModelConfig.comc_dynamic_bicycle_model', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mlp_model', full_name='apollo.common.VehicleModelConfig.mlp_model', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VEHICLEMODELCONFIG_MODELTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=81,
  serialized_end=508,
)


_REARCENTEREDKINEMATICBICYCLEMODELCONFIG = _descriptor.Descriptor(
  name='RearCenteredKinematicBicycleModelConfig',
  full_name='apollo.common.RearCenteredKinematicBicycleModelConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dt', full_name='apollo.common.RearCenteredKinematicBicycleModelConfig.dt', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=510,
  serialized_end=563,
)


_COMCENTEREDDYNAMICBICYCLEMODELCONFIG = _descriptor.Descriptor(
  name='ComCenteredDynamicBicycleModelConfig',
  full_name='apollo.common.ComCenteredDynamicBicycleModelConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dt', full_name='apollo.common.ComCenteredDynamicBicycleModelConfig.dt', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=565,
  serialized_end=615,
)


_MLPMODELCONFIG = _descriptor.Descriptor(
  name='MlpModelConfig',
  full_name='apollo.common.MlpModelConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dt', full_name='apollo.common.MlpModelConfig.dt', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=617,
  serialized_end=645,
)

_VEHICLEMODELCONFIG.fields_by_name['model_type'].enum_type = _VEHICLEMODELCONFIG_MODELTYPE
_VEHICLEMODELCONFIG.fields_by_name['rc_kinematic_bicycle_model'].message_type = _REARCENTEREDKINEMATICBICYCLEMODELCONFIG
_VEHICLEMODELCONFIG.fields_by_name['comc_dynamic_bicycle_model'].message_type = _COMCENTEREDDYNAMICBICYCLEMODELCONFIG
_VEHICLEMODELCONFIG.fields_by_name['mlp_model'].message_type = _MLPMODELCONFIG
_VEHICLEMODELCONFIG_MODELTYPE.containing_type = _VEHICLEMODELCONFIG
DESCRIPTOR.message_types_by_name['VehicleModelConfig'] = _VEHICLEMODELCONFIG
DESCRIPTOR.message_types_by_name['RearCenteredKinematicBicycleModelConfig'] = _REARCENTEREDKINEMATICBICYCLEMODELCONFIG
DESCRIPTOR.message_types_by_name['ComCenteredDynamicBicycleModelConfig'] = _COMCENTEREDDYNAMICBICYCLEMODELCONFIG
DESCRIPTOR.message_types_by_name['MlpModelConfig'] = _MLPMODELCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

VehicleModelConfig = _reflection.GeneratedProtocolMessageType('VehicleModelConfig', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLEMODELCONFIG,
  '__module__' : 'modules.common.vehicle_model.proto.vehicle_model_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.common.VehicleModelConfig)
  })
_sym_db.RegisterMessage(VehicleModelConfig)

RearCenteredKinematicBicycleModelConfig = _reflection.GeneratedProtocolMessageType('RearCenteredKinematicBicycleModelConfig', (_message.Message,), {
  'DESCRIPTOR' : _REARCENTEREDKINEMATICBICYCLEMODELCONFIG,
  '__module__' : 'modules.common.vehicle_model.proto.vehicle_model_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.common.RearCenteredKinematicBicycleModelConfig)
  })
_sym_db.RegisterMessage(RearCenteredKinematicBicycleModelConfig)

ComCenteredDynamicBicycleModelConfig = _reflection.GeneratedProtocolMessageType('ComCenteredDynamicBicycleModelConfig', (_message.Message,), {
  'DESCRIPTOR' : _COMCENTEREDDYNAMICBICYCLEMODELCONFIG,
  '__module__' : 'modules.common.vehicle_model.proto.vehicle_model_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.common.ComCenteredDynamicBicycleModelConfig)
  })
_sym_db.RegisterMessage(ComCenteredDynamicBicycleModelConfig)

MlpModelConfig = _reflection.GeneratedProtocolMessageType('MlpModelConfig', (_message.Message,), {
  'DESCRIPTOR' : _MLPMODELCONFIG,
  '__module__' : 'modules.common.vehicle_model.proto.vehicle_model_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.common.MlpModelConfig)
  })
_sym_db.RegisterMessage(MlpModelConfig)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/control/proto/control_common_conf.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.canbus.proto import chassis_pb2 as modules_dot_canbus_dot_proto_dot_chassis__pb2
from modules.control.proto import pad_msg_pb2 as modules_dot_control_dot_proto_dot_pad__msg__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/control/proto/control_common_conf.proto',
  package='apollo.control',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/modules/control/proto/control_common_conf.proto\x12\x0e\x61pollo.control\x1a\"modules/canbus/proto/chassis.proto\x1a#modules/control/proto/pad_msg.proto\"\xde\t\n\x11\x43ontrolCommonConf\x12!\n\x15\x63ontrol_test_duration\x18\x01 \x01(\x01:\x02-1\x12\x1f\n\x10\x65nable_csv_debug\x18\x02 \x01(\x08:\x05\x66\x61lse\x12+\n\x1c\x65nable_speed_station_preview\x18\x03 \x01(\x08:\x05\x66\x61lse\x12#\n\x14is_control_test_mode\x18\x04 \x01(\x08:\x05\x66\x61lse\x12*\n\x1buse_preview_speed_for_table\x18\x05 \x01(\x08:\x05\x66\x61lse\x12+\n\x1c\x65nable_input_timestamp_check\x18\x06 \x01(\x08:\x05\x66\x61lse\x12%\n\x19max_localization_miss_num\x18\x07 \x01(\x05:\x02\x32\x30\x12 \n\x14max_chassis_miss_num\x18\x08 \x01(\x05:\x02\x32\x30\x12!\n\x15max_planning_miss_num\x18\t \x01(\x05:\x02\x32\x30\x12+\n\x1dmax_acceleration_when_stopped\x18\n \x01(\x01:\x04\x30.01\x12\x1d\n\x10steer_angle_rate\x18\x0b \x01(\x01:\x03\x31\x30\x30\x12#\n\x15\x65nable_gain_scheduler\x18\x0c \x01(\x08:\x04true\x12\x1d\n\x0fset_steer_limit\x18\r \x01(\x08:\x04true\x12\"\n\x13\x65nable_slope_offset\x18\x0e \x01(\x08:\x05\x66\x61lse\x12\x1f\n\x10lock_steer_speed\x18\x0f \x01(\x01:\x05\x30.081\x12\x32\n#enable_navigation_mode_error_filter\x18\x10 \x01(\x08:\x05\x66\x61lse\x12\x34\n&enable_navigation_mode_position_update\x18\x11 \x01(\x08:\x04true\x12%\n\x17\x65nable_persistent_estop\x18\x12 \x01(\x08:\x04true\x12\x16\n\x0e\x63ontrol_period\x18\x13 \x01(\x01\x12!\n\x19max_planning_interval_sec\x18\x14 \x01(\x01\x12$\n\x1cmax_planning_delay_threshold\x18\x15 \x01(\x01\x12\x38\n\x0c\x64riving_mode\x18\x16 \x01(\x0e\x32\".apollo.canbus.Chassis.DrivingMode\x12-\n\x06\x61\x63tion\x18\x17 \x01(\x0e\x32\x1d.apollo.control.DrivingAction\x12\x18\n\x10soft_estop_brake\x18\x18 \x01(\x01\x12\'\n\x1fmax_steering_percentage_allowed\x18\x1a \x01(\x05\x12\x1f\n\x17max_status_interval_sec\x18\x1b \x01(\x01\x12\x19\n\x11trajectory_period\x18\x1e \x01(\x01\x12\x16\n\x0e\x63hassis_period\x18\x1f \x01(\x01\x12\x1b\n\x13localization_period\x18  \x01(\x01\x12 \n\x18minimum_speed_resolution\x18! \x01(\x01\x12\x1b\n\x13query_relative_time\x18# \x01(\x01\x12 \n\x18minimum_speed_protection\x18$ \x01(\x01\x12)\n\x1cmax_path_remain_when_stopped\x18% \x01(\x01:\x03\x30.3'
  ,
  dependencies=[modules_dot_canbus_dot_proto_dot_chassis__pb2.DESCRIPTOR,modules_dot_control_dot_proto_dot_pad__msg__pb2.DESCRIPTOR,])




_CONTROLCOMMONCONF = _descriptor.Descriptor(
  name='ControlCommonConf',
  full_name='apollo.control.ControlCommonConf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='control_test_duration', full_name='apollo.control.ControlCommonConf.control_test_duration', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(-1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_csv_debug', full_name='apollo.control.ControlCommonConf.enable_csv_debug', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_speed_station_preview', full_name='apollo.control.ControlCommonConf.enable_speed_station_preview', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_control_test_mode', full_name='apollo.control.ControlCommonConf.is_control_test_mode', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_preview_speed_for_table', full_name='apollo.control.ControlCommonConf.use_preview_speed_for_table', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_input_timestamp_check', full_name='apollo.control.ControlCommonConf.enable_input_timestamp_check', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_localization_miss_num', full_name='apollo.control.ControlCommonConf.max_localization_miss_num', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=20,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_chassis_miss_num', full_name='apollo.control.ControlCommonConf.max_chassis_miss_num', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=20,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_planning_miss_num', full_name='apollo.control.ControlCommonConf.max_planning_miss_num', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=20,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_acceleration_when_stopped', full_name='apollo.control.ControlCommonConf.max_acceleration_when_stopped', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.01),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_angle_rate', full_name='apollo.control.ControlCommonConf.steer_angle_rate', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(100),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_gain_scheduler', full_name='apollo.control.ControlCommonConf.enable_gain_scheduler', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_steer_limit', full_name='apollo.control.ControlCommonConf.set_steer_limit', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_slope_offset', full_name='apollo.control.ControlCommonConf.enable_slope_offset', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lock_steer_speed', full_name='apollo.control.ControlCommonConf.lock_steer_speed', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.081),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_navigation_mode_error_filter', full_name='apollo.control.ControlCommonConf.enable_navigation_mode_error_filter', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_navigation_mode_position_update', full_name='apollo.control.ControlCommonConf.enable_navigation_mode_position_update', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_persistent_estop', full_name='apollo.control.ControlCommonConf.enable_persistent_estop', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='control_period', full_name='apollo.control.ControlCommonConf.control_period', index=18,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_planning_interval_sec', full_name='apollo.control.ControlCommonConf.max_planning_interval_sec', index=19,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_planning_delay_threshold', full_name='apollo.control.ControlCommonConf.max_planning_delay_threshold', index=20,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driving_mode', full_name='apollo.control.ControlCommonConf.driving_mode', index=21,
      number=22, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='apollo.control.ControlCommonConf.action', index=22,
      number=23, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='soft_estop_brake', full_name='apollo.control.ControlCommonConf.soft_estop_brake', index=23,
      number=24, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_steering_percentage_allowed', full_name='apollo.control.ControlCommonConf.max_steering_percentage_allowed', index=24,
      number=26, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_status_interval_sec', full_name='apollo.control.ControlCommonConf.max_status_interval_sec', index=25,
      number=27, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trajectory_period', full_name='apollo.control.ControlCommonConf.trajectory_period', index=26,
      number=30, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chassis_period', full_name='apollo.control.ControlCommonConf.chassis_period', index=27,
      number=31, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='localization_period', full_name='apollo.control.ControlCommonConf.localization_period', index=28,
      number=32, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minimum_speed_resolution', full_name='apollo.control.ControlCommonConf.minimum_speed_resolution', index=29,
      number=33, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_relative_time', full_name='apollo.control.ControlCommonConf.query_relative_time', index=30,
      number=35, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minimum_speed_protection', full_name='apollo.control.ControlCommonConf.minimum_speed_protection', index=31,
      number=36, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_path_remain_when_stopped', full_name='apollo.control.ControlCommonConf.max_path_remain_when_stopped', index=32,
      number=37, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.3),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=141,
  serialized_end=1387,
)

_CONTROLCOMMONCONF.fields_by_name['driving_mode'].enum_type = modules_dot_canbus_dot_proto_dot_chassis__pb2._CHASSIS_DRIVINGMODE
_CONTROLCOMMONCONF.fields_by_name['action'].enum_type = modules_dot_control_dot_proto_dot_pad__msg__pb2._DRIVINGACTION
DESCRIPTOR.message_types_by_name['ControlCommonConf'] = _CONTROLCOMMONCONF
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ControlCommonConf = _reflection.GeneratedProtocolMessageType('ControlCommonConf', (_message.Message,), {
  'DESCRIPTOR' : _CONTROLCOMMONCONF,
  '__module__' : 'modules.control.proto.control_common_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.control.ControlCommonConf)
  })
_sym_db.RegisterMessage(ControlCommonConf)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cyber/proto/classic_conf.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cyber/proto/classic_conf.proto',
  package='apollo.cyber.proto',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1e\x63yber/proto/classic_conf.proto\x12\x12\x61pollo.cyber.proto\"@\n\x0b\x43lassicTask\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x04prio\x18\x02 \x01(\r:\x01\x31\x12\x12\n\ngroup_name\x18\x03 \x01(\t\"\xc5\x01\n\nSchedGroup\x12\x19\n\x04name\x18\x01 \x02(\t:\x0b\x64\x65\x66\x61ult_grp\x12\x15\n\rprocessor_num\x18\x02 \x01(\r\x12\x10\n\x08\x61\x66\x66inity\x18\x03 \x01(\t\x12\x0e\n\x06\x63puset\x18\x04 \x01(\t\x12\x18\n\x10processor_policy\x18\x05 \x01(\t\x12\x19\n\x0eprocessor_prio\x18\x06 \x01(\x05:\x01\x30\x12.\n\x05tasks\x18\x07 \x03(\x0b\x32\x1f.apollo.cyber.proto.ClassicTask\"=\n\x0b\x43lassicConf\x12.\n\x06groups\x18\x01 \x03(\x0b\x32\x1e.apollo.cyber.proto.SchedGroup'
)




_CLASSICTASK = _descriptor.Descriptor(
  name='ClassicTask',
  full_name='apollo.cyber.proto.ClassicTask',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.cyber.proto.ClassicTask.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prio', full_name='apollo.cyber.proto.ClassicTask.prio', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group_name', full_name='apollo.cyber.proto.ClassicTask.group_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=54,
  serialized_end=118,
)


_SCHEDGROUP = _descriptor.Descriptor(
  name='SchedGroup',
  full_name='apollo.cyber.proto.SchedGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.cyber.proto.SchedGroup.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=True, default_value=b"default_grp".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='processor_num', full_name='apollo.cyber.proto.SchedGroup.processor_num', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='affinity', full_name='apollo.cyber.proto.SchedGroup.affinity', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cpuset', full_name='apollo.cyber.proto.SchedGroup.cpuset', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='processor_policy', full_name='apollo.cyber.proto.SchedGroup.processor_policy', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='processor_prio', full_name='apollo.cyber.proto.SchedGroup.processor_prio', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tasks', full_name='apollo.cyber.proto.SchedGroup.tasks', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=318,
)


_CLASSICCONF = _descriptor.Descriptor(
  name='ClassicConf',
  full_name='apollo.cyber.proto.ClassicConf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='groups', full_name='apollo.cyber.proto.ClassicConf.groups', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=320,
  serialized_end=381,
)

_SCHEDGROUP.fields_by_name['tasks'].message_type = _CLASSICTASK
_CLASSICCONF.fields_by_name['groups'].message_type = _SCHEDGROUP
DESCRIPTOR.message_types_by_name['ClassicTask'] = _CLASSICTASK
DESCRIPTOR.message_types_by_name['SchedGroup'] = _SCHEDGROUP
DESCRIPTOR.message_types_by_name['ClassicConf'] = _CLASSICCONF
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClassicTask = _reflection.GeneratedProtocolMessageType('ClassicTask', (_message.Message,), {
  'DESCRIPTOR' : _CLASSICTASK,
  '__module__' : 'cyber.proto.classic_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.ClassicTask)
  })
_sym_db.RegisterMessage(ClassicTask)

SchedGroup = _reflection.GeneratedProtocolMessageType('SchedGroup', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDGROUP,
  '__module__' : 'cyber.proto.classic_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.SchedGroup)
  })
_sym_db.RegisterMessage(SchedGroup)

ClassicConf = _reflection.GeneratedProtocolMessageType('ClassicConf', (_message.Message,), {
  'DESCRIPTOR' : _CLASSICCONF,
  '__module__' : 'cyber.proto.classic_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.ClassicConf)
  })
_sym_db.RegisterMessage(ClassicConf)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/v2x/proto/v2x_junction.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import geometry_pb2 as modules_dot_common_dot_proto_dot_geometry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/v2x/proto/v2x_junction.proto',
  package='apollo.v2x',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$modules/v2x/proto/v2x_junction.proto\x12\napollo.v2x\x1a#modules/common/proto/geometry.proto\"\x10\n\x02Id\x12\n\n\x02id\x18\x01 \x01(\x0c\"\x8c\x03\n\x08Junction\x12\x1a\n\x02id\x18\x01 \x01(\x0b\x32\x0e.apollo.v2x.Id\x12\'\n\x07polygon\x18\x02 \x01(\x0b\x32\x16.apollo.common.Polygon\x12$\n\x0c\x63rosswalk_id\x18\x03 \x03(\x0b\x32\x0e.apollo.v2x.Id\x12\"\n\noverlap_id\x18\x04 \x03(\x0b\x32\x0e.apollo.v2x.Id\x12\x1c\n\x11num_road_segments\x18\x05 \x01(\x05:\x01\x34\x12\x1f\n\x07lane_id\x18\x06 \x03(\x0b\x32\x0e.apollo.v2x.Id\x12\'\n\x04type\x18\x07 \x01(\x0e\x32\x19.apollo.v2x.Junction.Type\x12\x30\n\tedge_type\x18\x08 \x03(\x0e\x32\x1d.apollo.v2x.Junction.EdgeType\"0\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07IN_ROAD\x10\x01\x12\x0e\n\nCROSS_ROAD\x10\x02\"%\n\x08\x45\x64geType\x12\x0c\n\x08PHYSICAL\x10\x00\x12\x0b\n\x07VIRTUAL\x10\x01'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_geometry__pb2.DESCRIPTOR,])



_JUNCTION_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='apollo.v2x.Junction.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IN_ROAD', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CROSS_ROAD', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=417,
  serialized_end=465,
)
_sym_db.RegisterEnumDescriptor(_JUNCTION_TYPE)

_JUNCTION_EDGETYPE = _descriptor.EnumDescriptor(
  name='EdgeType',
  full_name='apollo.v2x.Junction.EdgeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PHYSICAL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VIRTUAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=467,
  serialized_end=504,
)
_sym_db.RegisterEnumDescriptor(_JUNCTION_EDGETYPE)


_ID = _descriptor.Descriptor(
  name='Id',
  full_name='apollo.v2x.Id',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.v2x.Id.id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=89,
  serialized_end=105,
)


_JUNCTION = _descriptor.Descriptor(
  name='Junction',
  full_name='apollo.v2x.Junction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.v2x.Junction.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='polygon', full_name='apollo.v2x.Junction.polygon', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crosswalk_id', full_name='apollo.v2x.Junction.crosswalk_id', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overlap_id', full_name='apollo.v2x.Junction.overlap_id', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_road_segments', full_name='apollo.v2x.Junction.num_road_segments', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=4,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_id', full_name='apollo.v2x.Junction.lane_id', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.v2x.Junction.type', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='edge_type', full_name='apollo.v2x.Junction.edge_type', index=7,
      number=8, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _JUNCTION_TYPE,
    _JUNCTION_EDGETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=108,
  serialized_end=504,
)

_JUNCTION.fields_by_name['id'].message_type = _ID
_JUNCTION.fields_by_name['polygon'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POLYGON
_JUNCTION.fields_by_name['crosswalk_id'].message_type = _ID
_JUNCTION.fields_by_name['overlap_id'].message_type = _ID
_JUNCTION.fields_by_name['lane_id'].message_type = _ID
_JUNCTION.fields_by_name['type'].enum_type = _JUNCTION_TYPE
_JUNCTION.fields_by_name['edge_type'].enum_type = _JUNCTION_EDGETYPE
_JUNCTION_TYPE.containing_type = _JUNCTION
_JUNCTION_EDGETYPE.containing_type = _JUNCTION
DESCRIPTOR.message_types_by_name['Id'] = _ID
DESCRIPTOR.message_types_by_name['Junction'] = _JUNCTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Id = _reflection.GeneratedProtocolMessageType('Id', (_message.Message,), {
  'DESCRIPTOR' : _ID,
  '__module__' : 'modules.v2x.proto.v2x_junction_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.Id)
  })
_sym_db.RegisterMessage(Id)

Junction = _reflection.GeneratedProtocolMessageType('Junction', (_message.Message,), {
  'DESCRIPTOR' : _JUNCTION,
  '__module__' : 'modules.v2x.proto.v2x_junction_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.Junction)
  })
_sym_db.RegisterMessage(Junction)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/drivers/velodyne/proto/velodyne.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/drivers/velodyne/proto/velodyne.proto',
  package='apollo.drivers.velodyne',
  syntax='proto2',
  serialized_pb=_b('\n-modules/drivers/velodyne/proto/velodyne.proto\x12\x17\x61pollo.drivers.velodyne\x1a!modules/common/proto/header.proto\"-\n\x0eVelodynePacket\x12\r\n\x05stamp\x18\x01 \x01(\x04\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"\xb3\x02\n\x0cVelodyneScan\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12-\n\x05model\x18\x02 \x01(\x0e\x32\x1e.apollo.drivers.velodyne.Model\x12+\n\x04mode\x18\x03 \x01(\x0e\x32\x1d.apollo.drivers.velodyne.Mode\x12<\n\x0b\x66iring_pkts\x18\x04 \x03(\x0b\x32\'.apollo.drivers.velodyne.VelodynePacket\x12\x41\n\x10positioning_pkts\x18\x05 \x03(\x0b\x32\'.apollo.drivers.velodyne.VelodynePacket\x12\n\n\x02sn\x18\x06 \x01(\t\x12\x13\n\x08\x62\x61setime\x18\x07 \x01(\x04:\x01\x30*q\n\x05Model\x12\n\n\x06UNKOWN\x10\x00\x12\x0e\n\nHDL64E_S3S\x10\x01\x12\x0e\n\nHDL64E_S3D\x10\x02\x12\r\n\tHDL64E_S2\x10\x03\x12\n\n\x06HDL32E\x10\x04\x12\t\n\x05VLP16\x10\x05\x12\n\n\x06VLP32C\x10\x06\x12\n\n\x06VLS128\x10\x07*)\n\x04Mode\x12\r\n\tSTRONGEST\x10\x01\x12\x08\n\x04LAST\x10\x02\x12\x08\n\x04\x44UAL\x10\x03')
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,])

_MODEL = _descriptor.EnumDescriptor(
  name='Model',
  full_name='apollo.drivers.velodyne.Model',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKOWN', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HDL64E_S3S', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HDL64E_S3D', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HDL64E_S2', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HDL32E', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VLP16', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VLP32C', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VLS128', index=7, number=7,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=466,
  serialized_end=579,
)
_sym_db.RegisterEnumDescriptor(_MODEL)

Model = enum_type_wrapper.EnumTypeWrapper(_MODEL)
_MODE = _descriptor.EnumDescriptor(
  name='Mode',
  full_name='apollo.drivers.velodyne.Mode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STRONGEST', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LAST', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DUAL', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=581,
  serialized_end=622,
)
_sym_db.RegisterEnumDescriptor(_MODE)

Mode = enum_type_wrapper.EnumTypeWrapper(_MODE)
UNKOWN = 0
HDL64E_S3S = 1
HDL64E_S3D = 2
HDL64E_S2 = 3
HDL32E = 4
VLP16 = 5
VLP32C = 6
VLS128 = 7
STRONGEST = 1
LAST = 2
DUAL = 3



_VELODYNEPACKET = _descriptor.Descriptor(
  name='VelodynePacket',
  full_name='apollo.drivers.velodyne.VelodynePacket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stamp', full_name='apollo.drivers.velodyne.VelodynePacket.stamp', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data', full_name='apollo.drivers.velodyne.VelodynePacket.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=109,
  serialized_end=154,
)


_VELODYNESCAN = _descriptor.Descriptor(
  name='VelodyneScan',
  full_name='apollo.drivers.velodyne.VelodyneScan',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.drivers.velodyne.VelodyneScan.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='model', full_name='apollo.drivers.velodyne.VelodyneScan.model', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mode', full_name='apollo.drivers.velodyne.VelodyneScan.mode', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='firing_pkts', full_name='apollo.drivers.velodyne.VelodyneScan.firing_pkts', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='positioning_pkts', full_name='apollo.drivers.velodyne.VelodyneScan.positioning_pkts', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sn', full_name='apollo.drivers.velodyne.VelodyneScan.sn', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='basetime', full_name='apollo.drivers.velodyne.VelodyneScan.basetime', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=157,
  serialized_end=464,
)

_VELODYNESCAN.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_VELODYNESCAN.fields_by_name['model'].enum_type = _MODEL
_VELODYNESCAN.fields_by_name['mode'].enum_type = _MODE
_VELODYNESCAN.fields_by_name['firing_pkts'].message_type = _VELODYNEPACKET
_VELODYNESCAN.fields_by_name['positioning_pkts'].message_type = _VELODYNEPACKET
DESCRIPTOR.message_types_by_name['VelodynePacket'] = _VELODYNEPACKET
DESCRIPTOR.message_types_by_name['VelodyneScan'] = _VELODYNESCAN
DESCRIPTOR.enum_types_by_name['Model'] = _MODEL
DESCRIPTOR.enum_types_by_name['Mode'] = _MODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

VelodynePacket = _reflection.GeneratedProtocolMessageType('VelodynePacket', (_message.Message,), dict(
  DESCRIPTOR = _VELODYNEPACKET,
  __module__ = 'modules.drivers.velodyne.proto.velodyne_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.velodyne.VelodynePacket)
  ))
_sym_db.RegisterMessage(VelodynePacket)

VelodyneScan = _reflection.GeneratedProtocolMessageType('VelodyneScan', (_message.Message,), dict(
  DESCRIPTOR = _VELODYNESCAN,
  __module__ = 'modules.drivers.velodyne.proto.velodyne_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.velodyne.VelodyneScan)
  ))
_sym_db.RegisterMessage(VelodyneScan)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/dreamview/proto/hmi_status.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2
from modules.monitor.proto import system_status_pb2 as modules_dot_monitor_dot_proto_dot_system__status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/dreamview/proto/hmi_status.proto',
  package='apollo.dreamview',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n(modules/dreamview/proto/hmi_status.proto\x12\x10\x61pollo.dreamview\x1a!modules/common/proto/header.proto\x1a)modules/monitor/proto/system_status.proto\"\xa8\x05\n\tHMIStatus\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\r\n\x05modes\x18\x02 \x03(\t\x12\x14\n\x0c\x63urrent_mode\x18\x03 \x01(\t\x12\x0c\n\x04maps\x18\x04 \x03(\t\x12\x13\n\x0b\x63urrent_map\x18\x05 \x01(\t\x12\x10\n\x08vehicles\x18\x06 \x03(\t\x12\x17\n\x0f\x63urrent_vehicle\x18\x07 \x01(\t\x12\x39\n\x07modules\x18\x08 \x03(\x0b\x32(.apollo.dreamview.HMIStatus.ModulesEntry\x12R\n\x14monitored_components\x18\t \x03(\x0b\x32\x34.apollo.dreamview.HMIStatus.MonitoredComponentsEntry\x12\x14\n\x0c\x64ocker_image\x18\n \x01(\t\x12\x13\n\x0butm_zone_id\x18\x0b \x01(\x05\x12\x15\n\rpassenger_msg\x18\x0c \x01(\t\x12J\n\x10other_components\x18\r \x03(\x0b\x32\x30.apollo.dreamview.HMIStatus.OtherComponentsEntry\x1a.\n\x0cModulesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a[\n\x18MonitoredComponentsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12.\n\x05value\x18\x02 \x01(\x0b\x32\x1f.apollo.monitor.ComponentStatus:\x02\x38\x01\x1aW\n\x14OtherComponentsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12.\n\x05value\x18\x02 \x01(\x0b\x32\x1f.apollo.monitor.ComponentStatus:\x02\x38\x01'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,modules_dot_monitor_dot_proto_dot_system__status__pb2.DESCRIPTOR,])




_HMISTATUS_MODULESENTRY = _descriptor.Descriptor(
  name='ModulesEntry',
  full_name='apollo.dreamview.HMIStatus.ModulesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='apollo.dreamview.HMIStatus.ModulesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.dreamview.HMIStatus.ModulesEntry.value', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=593,
  serialized_end=639,
)

_HMISTATUS_MONITOREDCOMPONENTSENTRY = _descriptor.Descriptor(
  name='MonitoredComponentsEntry',
  full_name='apollo.dreamview.HMIStatus.MonitoredComponentsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='apollo.dreamview.HMIStatus.MonitoredComponentsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.dreamview.HMIStatus.MonitoredComponentsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=641,
  serialized_end=732,
)

_HMISTATUS_OTHERCOMPONENTSENTRY = _descriptor.Descriptor(
  name='OtherComponentsEntry',
  full_name='apollo.dreamview.HMIStatus.OtherComponentsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='apollo.dreamview.HMIStatus.OtherComponentsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.dreamview.HMIStatus.OtherComponentsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=734,
  serialized_end=821,
)

_HMISTATUS = _descriptor.Descriptor(
  name='HMIStatus',
  full_name='apollo.dreamview.HMIStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.dreamview.HMIStatus.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modes', full_name='apollo.dreamview.HMIStatus.modes', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current_mode', full_name='apollo.dreamview.HMIStatus.current_mode', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maps', full_name='apollo.dreamview.HMIStatus.maps', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current_map', full_name='apollo.dreamview.HMIStatus.current_map', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehicles', full_name='apollo.dreamview.HMIStatus.vehicles', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current_vehicle', full_name='apollo.dreamview.HMIStatus.current_vehicle', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modules', full_name='apollo.dreamview.HMIStatus.modules', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='monitored_components', full_name='apollo.dreamview.HMIStatus.monitored_components', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='docker_image', full_name='apollo.dreamview.HMIStatus.docker_image', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='utm_zone_id', full_name='apollo.dreamview.HMIStatus.utm_zone_id', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='passenger_msg', full_name='apollo.dreamview.HMIStatus.passenger_msg', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='other_components', full_name='apollo.dreamview.HMIStatus.other_components', index=12,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_HMISTATUS_MODULESENTRY, _HMISTATUS_MONITOREDCOMPONENTSENTRY, _HMISTATUS_OTHERCOMPONENTSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=141,
  serialized_end=821,
)

_HMISTATUS_MODULESENTRY.containing_type = _HMISTATUS
_HMISTATUS_MONITOREDCOMPONENTSENTRY.fields_by_name['value'].message_type = modules_dot_monitor_dot_proto_dot_system__status__pb2._COMPONENTSTATUS
_HMISTATUS_MONITOREDCOMPONENTSENTRY.containing_type = _HMISTATUS
_HMISTATUS_OTHERCOMPONENTSENTRY.fields_by_name['value'].message_type = modules_dot_monitor_dot_proto_dot_system__status__pb2._COMPONENTSTATUS
_HMISTATUS_OTHERCOMPONENTSENTRY.containing_type = _HMISTATUS
_HMISTATUS.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_HMISTATUS.fields_by_name['modules'].message_type = _HMISTATUS_MODULESENTRY
_HMISTATUS.fields_by_name['monitored_components'].message_type = _HMISTATUS_MONITOREDCOMPONENTSENTRY
_HMISTATUS.fields_by_name['other_components'].message_type = _HMISTATUS_OTHERCOMPONENTSENTRY
DESCRIPTOR.message_types_by_name['HMIStatus'] = _HMISTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HMIStatus = _reflection.GeneratedProtocolMessageType('HMIStatus', (_message.Message,), {

  'ModulesEntry' : _reflection.GeneratedProtocolMessageType('ModulesEntry', (_message.Message,), {
    'DESCRIPTOR' : _HMISTATUS_MODULESENTRY,
    '__module__' : 'modules.dreamview.proto.hmi_status_pb2'
    # @@protoc_insertion_point(class_scope:apollo.dreamview.HMIStatus.ModulesEntry)
    })
  ,

  'MonitoredComponentsEntry' : _reflection.GeneratedProtocolMessageType('MonitoredComponentsEntry', (_message.Message,), {
    'DESCRIPTOR' : _HMISTATUS_MONITOREDCOMPONENTSENTRY,
    '__module__' : 'modules.dreamview.proto.hmi_status_pb2'
    # @@protoc_insertion_point(class_scope:apollo.dreamview.HMIStatus.MonitoredComponentsEntry)
    })
  ,

  'OtherComponentsEntry' : _reflection.GeneratedProtocolMessageType('OtherComponentsEntry', (_message.Message,), {
    'DESCRIPTOR' : _HMISTATUS_OTHERCOMPONENTSENTRY,
    '__module__' : 'modules.dreamview.proto.hmi_status_pb2'
    # @@protoc_insertion_point(class_scope:apollo.dreamview.HMIStatus.OtherComponentsEntry)
    })
  ,
  'DESCRIPTOR' : _HMISTATUS,
  '__module__' : 'modules.dreamview.proto.hmi_status_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.HMIStatus)
  })
_sym_db.RegisterMessage(HMIStatus)
_sym_db.RegisterMessage(HMIStatus.ModulesEntry)
_sym_db.RegisterMessage(HMIStatus.MonitoredComponentsEntry)
_sym_db.RegisterMessage(HMIStatus.OtherComponentsEntry)


_HMISTATUS_MODULESENTRY._options = None
_HMISTATUS_MONITOREDCOMPONENTSENTRY._options = None
_HMISTATUS_OTHERCOMPONENTSENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/bridge/proto/udp_bridge_remote_info.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/bridge/proto/udp_bridge_remote_info.proto',
  package='apollo.bridge',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1modules/bridge/proto/udp_bridge_remote_info.proto\x12\rapollo.bridge\"v\n\x19UDPBridgeSenderRemoteInfo\x12\x1c\n\tremote_ip\x18\x01 \x01(\t:\t127.0.0.1\x12\x19\n\x0bremote_port\x18\x02 \x01(\x05:\x04\x38\x39\x30\x30\x12 \n\nproto_name\x18\x03 \x01(\t:\x0cProtoMsgName\"\x8c\x01\n\x1bUDPBridgeReceiverRemoteInfo\x12\x14\n\ntopic_name\x18\x01 \x01(\t:\x00\x12\x17\n\tbind_port\x18\x02 \x01(\x05:\x04\x38\x35\x30\x30\x12 \n\nproto_name\x18\x03 \x01(\t:\x0cProtoMsgName\x12\x1c\n\x0e\x65nable_timeout\x18\x04 \x01(\x08:\x04true'
)




_UDPBRIDGESENDERREMOTEINFO = _descriptor.Descriptor(
  name='UDPBridgeSenderRemoteInfo',
  full_name='apollo.bridge.UDPBridgeSenderRemoteInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='remote_ip', full_name='apollo.bridge.UDPBridgeSenderRemoteInfo.remote_ip', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"127.0.0.1".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remote_port', full_name='apollo.bridge.UDPBridgeSenderRemoteInfo.remote_port', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=8900,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proto_name', full_name='apollo.bridge.UDPBridgeSenderRemoteInfo.proto_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"ProtoMsgName".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=186,
)


_UDPBRIDGERECEIVERREMOTEINFO = _descriptor.Descriptor(
  name='UDPBridgeReceiverRemoteInfo',
  full_name='apollo.bridge.UDPBridgeReceiverRemoteInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='topic_name', full_name='apollo.bridge.UDPBridgeReceiverRemoteInfo.topic_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bind_port', full_name='apollo.bridge.UDPBridgeReceiverRemoteInfo.bind_port', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=8500,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proto_name', full_name='apollo.bridge.UDPBridgeReceiverRemoteInfo.proto_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"ProtoMsgName".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_timeout', full_name='apollo.bridge.UDPBridgeReceiverRemoteInfo.enable_timeout', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=189,
  serialized_end=329,
)

DESCRIPTOR.message_types_by_name['UDPBridgeSenderRemoteInfo'] = _UDPBRIDGESENDERREMOTEINFO
DESCRIPTOR.message_types_by_name['UDPBridgeReceiverRemoteInfo'] = _UDPBRIDGERECEIVERREMOTEINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UDPBridgeSenderRemoteInfo = _reflection.GeneratedProtocolMessageType('UDPBridgeSenderRemoteInfo', (_message.Message,), {
  'DESCRIPTOR' : _UDPBRIDGESENDERREMOTEINFO,
  '__module__' : 'modules.bridge.proto.udp_bridge_remote_info_pb2'
  # @@protoc_insertion_point(class_scope:apollo.bridge.UDPBridgeSenderRemoteInfo)
  })
_sym_db.RegisterMessage(UDPBridgeSenderRemoteInfo)

UDPBridgeReceiverRemoteInfo = _reflection.GeneratedProtocolMessageType('UDPBridgeReceiverRemoteInfo', (_message.Message,), {
  'DESCRIPTOR' : _UDPBRIDGERECEIVERREMOTEINFO,
  '__module__' : 'modules.bridge.proto.udp_bridge_remote_info_pb2'
  # @@protoc_insertion_point(class_scope:apollo.bridge.UDPBridgeReceiverRemoteInfo)
  })
_sym_db.RegisterMessage(UDPBridgeReceiverRemoteInfo)


# @@protoc_insertion_point(module_scope)
